@@ -159,6 +159,15 @@ class StringChain(object):
             self.ignored = 0
         #assert self._assert_invariants()
 
+    def clear(self):
+        """ Empty it out. """
+        #assert self._assert_invariants()
+        self.d.clear()
+        self.ignored = 0
+        self.tailignored = 0
+        self.len = 0
+        #assert self._assert_invariants()
+
     def copy(self):
         n = self.__class__()
         n.ignored = self.ignored
